Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_string_ref.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_string_ref.hh')
-rw-r--r--source/blender/blenlib/BLI_string_ref.hh14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenlib/BLI_string_ref.hh b/source/blender/blenlib/BLI_string_ref.hh
index 6a569bee1aa..3c670c4f2b8 100644
--- a/source/blender/blenlib/BLI_string_ref.hh
+++ b/source/blender/blenlib/BLI_string_ref.hh
@@ -20,13 +20,13 @@
/** \file
* \ingroup bli
*
* A `BLI::StringRef` references a const char array owned by someone else. It is just a pointer and
* a size. Since the memory is not owned, StringRef should not be used to transfer ownership of the
* string. The data referenced by a StringRef cannot be mutated through it.
*
* A StringRef is NOT null-terminated. This makes it much more powerful within C++, because we can
* also cut off parts of the end without creating a copy. When interfacing with C code that expects
* null-terminated strings, `BLI::StringRefNull` can be used. It is essentially the same as
* StringRef, but with the restriction that the string has to be null-terminated.
*
* Whenever possible, string parameters should be of type StringRef and the string return type
@@ -34,7 +34,7 @@
* return it when the string exists only in the scope of the function. This convention makes
* functions usable in the most contexts.
*
* BLI::StringRef vs. std::string_view:
* Both types are certainly very similar. The main benefit of using StringRef in Blender is that
* this allows us to add convenience methods at any time. Especially, when doing a lot of string
* manipulation, this helps to keep the code clean. Furthermore, we need StringRefNull anyway,
@@ -49,7 +49,7 @@
#include "BLI_array_ref.hh"
#include "BLI_utildefines.h"
-namespace BLI {
+namespace blender {
class StringRef;
@@ -345,6 +345,6 @@ inline StringRef StringRefBase::substr(uint start, uint size) const
return StringRef(m_data + start, size);
}
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_STRING_REF_HH__ */
@@ -20,13 +20,13 @@
* \ingroup bli
*
- * A `BLI::StringRef` references a const char array owned by someone else. It is just a pointer and
- * a size. Since the memory is not owned, StringRef should not be used to transfer ownership of the
- * string. The data referenced by a StringRef cannot be mutated through it.
+ * A `blender::StringRef` references a const char array owned by someone else. It is just a pointer
+ * and a size. Since the memory is not owned, StringRef should not be used to transfer ownership of
+ * the string. The data referenced by a StringRef cannot be mutated through it.
*
* A StringRef is NOT null-terminated. This makes it much more powerful within C++, because we can
@@ -20,13 +20,13 @@
* A StringRef is NOT null-terminated. This makes it much more powerful within C++, because we can
* also cut off parts of the end without creating a copy. When interfacing with C code that expects
- * null-terminated strings, `BLI::StringRefNull` can be used. It is essentially the same as
+ * null-terminated strings, `blender::StringRefNull` can be used. It is essentially the same as
* StringRef, but with the restriction that the string has to be null-terminated.
*
@@ -34,7 +34,7 @@
* functions usable in the most contexts.
*
- * BLI::StringRef vs. std::string_view:
+ * blender::StringRef vs. std::string_view:
* Both types are certainly very similar. The main benefit of using StringRef in Blender is that
* this allows us to add convenience methods at any time. Especially, when doing a lot of string